@@ -1,4 +1,4 @@
-#!C:\bld\peewee_1492418718767\_b_env\python.exe
+#!C:\bld\peewee_1498360060201\_b_env\python.exe
 
 import datetime
 import sys
@@ -111,6 +111,8 @@ def print_models(introspector, tables=None, preserve_order=False):
                 if col in primary_keys])
             pk_list = ', '.join("'%s'" % pk for pk in pk_field_names)
             print_('        primary_key = CompositeKey(%s)' % pk_list)
+        elif not primary_keys:
+            print_('        primary_key = False')
         print_('')
 
         seen.add(table)
